@@ -4,20 +4,20 @@
      .                  COVTYPE,COVPAR,COVMAT,LDCOV,C0VEC,LDC0,COV0,
      .                  EXTCOV,TREND,NTREND,RSEARCH,NSEARCH,NSMIN,NSMAX,
      .                  FWORK,LDFWRK,F0WORK,DIST,INDSNB,INDSNA,INDSRT,
-     .                  KWORK,NKWORK,RHSWORK,IPIV,MODE,MU,LAMBDA,LDLMBD,
-     .                  BITS,IERR)
+     .                  KWORK,NKWORK,RHSWORK,IPIV,MODE,MU,LDMU,LAMBDA,
+     .                  LDLMBD,BITS,retlm,IERR)
 
       IMPLICIT NONE
       INTEGER NX,NY,NZ,N,COVTYPE,TREND,NTREND,
      .        NSEARCH,NSMIN,NSMAX,MODE,IERR,INDSNB(*),INDSNA(*),
      .        INDSRT(*),IPIV(*),EXTRAP,DOG(NX,*),EXTCOV,LDCOV,
-     .        LDC0,LDFWRK,LDLMBD,NKWORK,bits(*)
+     .        LDC0,LDFWRK,LDLMBD,NKWORK,bits(*),LDMU,retlm
       DOUBLE PRECISION XSW,YSW,XNE,YNE,ANGLE,DX,DY,
      .                 XG(*),YG(*),ZG(NX,*),VARG(NX,*),
      .                 LON(*),LAT(*),Z(*),COVMAT(LDCOV,*),C0VEC(LDC0,*),
      .                 COV0,RSEARCH,FWORK(LDFWRK,*),F0WORK(NTREND,*),
-     .                 DIST(*),KWORK(NKWORK,*),RHSWORK(*),MU(*),
-     .                 LAMBDA(*),
+     .                 DIST(*),KWORK(NKWORK,*),RHSWORK(*),MU(LDMU,*),
+     .                 LAMBDA(LDLMBD,*),
      .                 COVPAR(*) 
 
 c     subroutine for kriging prediction on a grid
@@ -163,10 +163,19 @@ c     loop over all points and pass them to KRIGE:
       if (bits(1+nz).ne.0) then
          usesbbt=1 
       end if
-      PCNT=0
+      if (retlm.eq.1) then
+         PCNT=0
+      else
+         PCNT=1
+      end if
       DO 20 I=1,NX
          DO 10 J=1,NY
-            PCNT=PCNT+1
+c           grid point counter:
+            if (retlm.eq.1) then
+               PCNT=PCNT+1
+            end if
+c           put grid point counter in i,j pos.
+c           for later use in KRIGE ???????
             BITS(I+NY*(J-1)) = PCNT
             X0=XG(I)
             Y0=YG(J)
@@ -177,8 +186,10 @@ c           the main work is now done by KRIGE:
      .                 TREND,NTREND,RSEARCH,NSEARCH,NSMIN,NSMAX,FWORK,
      .                 LDFWRK,F0WORK,NTREND,
      .                 DIST,INDSNB,INDSNA,INDSRT,KWORK,
-     .                 NKWORK,RHSWORK,IPIV,MODE,MU,Z0,LAMBDA,LDLMBD,
+     .                 NKWORK,RHSWORK,IPIV,MODE,MU(1,PCNT),Z0,
+     .                 LAMBDA(1,PCNT),LDLMBD,
      .                 VAR0,BITS(nz+2+(pcnt-1)*n),USESBBT,IERR)
+c                           !!!!!!!!!!!!!!!!!!!!! 0-1 searchnb indicator
 c            if (usesbbt.ne.0) bits(nz+1)=TCNT
 
 c            name="xg"
