@@ -217,7 +217,7 @@ C      call matpr(name,rhswork,ns+ntrend,ndo,nkwork,dbglvl)
       IF (INFO.NE.0) THEN
          IERR=INFO
 c         write(*,*) "error in krige:", info
-         DO 54 I=1,NDO
+         DO 54 I=1,N0
             DO0(INDDO(I))=-1
  54      CONTINUE
          RETURN
