@@ -2,5 +2,5 @@
 
 void matrix_print(char *name, double *a, int *m, int *n, int *lda, int *level);
 
-void F77_SYMBOL(matpr) (char *name, double *a, int *m, int *n, int *lda, int *level);
+void F77_NAME(matpr) (char *name, double *a, int *m, int *n, int *lda, int *level);
 
